==> kubernetes-model-admissionregistration-6.5.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/NamedRuleWithOperationsFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface NamedRuleWithOperationsFluent<A extends NamedRuleWithOperationsFluent<A>> extends Fluent<A>{
  public A addToApiGroups(Integer index,String item);
  public A setToApiGroups(Integer index,String item);
  public A addToApiGroups(java.lang.String... items);
  public A addAllToApiGroups(Collection<String> items);
  public A removeFromApiGroups(java.lang.String... items);
  public A removeAllFromApiGroups(Collection<String> items);
  public List<String> getApiGroups();
  public String getApiGroup(Integer index);
  public String getFirstApiGroup();
  public String getLastApiGroup();
  public String getMatchingApiGroup(Predicate<String> predicate);
  public Boolean hasMatchingApiGroup(Predicate<String> predicate);
  public A withApiGroups(List<String> apiGroups);
  public A withApiGroups(java.lang.String... apiGroups);
  public Boolean hasApiGroups();
  public A addToApiVersions(Integer index,String item);
  public A setToApiVersions(Integer index,String item);
  public A addToApiVersions(java.lang.String... items);
  public A addAllToApiVersions(Collection<String> items);
  public A removeFromApiVersions(java.lang.String... items);
  public A removeAllFromApiVersions(Collection<String> items);
  public List<String> getApiVersions();
  public String getApiVersion(Integer index);
  public String getFirstApiVersion();
  public String getLastApiVersion();
  public String getMatchingApiVersion(Predicate<String> predicate);
  public Boolean hasMatchingApiVersion(Predicate<String> predicate);
  public A withApiVersions(List<String> apiVersions);
  public A withApiVersions(java.lang.String... apiVersions);
  public Boolean hasApiVersions();
  public A addToOperations(Integer index,String item);
  public A setToOperations(Integer index,String item);
  public A addToOperations(java.lang.String... items);
  public A addAllToOperations(Collection<String> items);
  public A removeFromOperations(java.lang.String... items);
  public A removeAllFromOperations(Collection<String> items);
  public List<String> getOperations();
  public String getOperation(Integer index);
  public String getFirstOperation();
  public String getLastOperation();
  public String getMatchingOperation(Predicate<String> predicate);
  public Boolean hasMatchingOperation(Predicate<String> predicate);
  public A withOperations(List<String> operations);
  public A withOperations(java.lang.String... operations);
  public Boolean hasOperations();
  public A addToResourceNames(Integer index,String item);
  public A setToResourceNames(Integer index,String item);
  public A addToResourceNames(java.lang.String... items);
  public A addAllToResourceNames(Collection<String> items);
  public A removeFromResourceNames(java.lang.String... items);
  public A removeAllFromResourceNames(Collection<String> items);
  public List<String> getResourceNames();
  public String getResourceName(Integer index);
  public String getFirstResourceName();
  public String getLastResourceName();
  public String getMatchingResourceName(Predicate<String> predicate);
  public Boolean hasMatchingResourceName(Predicate<String> predicate);
  public A withResourceNames(List<String> resourceNames);
  public A withResourceNames(java.lang.String... resourceNames);
  public Boolean hasResourceNames();
  public A addToResources(Integer index,String item);
  public A setToResources(Integer index,String item);
  public A addToResources(java.lang.String... items);
  public A addAllToResources(Collection<String> items);
  public A removeFromResources(java.lang.String... items);
  public A removeAllFromResources(Collection<String> items);
  public List<String> getResources();
  public String getResource(Integer index);
  public String getFirstResource();
  public String getLastResource();
  public String getMatchingResource(Predicate<String> predicate);
  public Boolean hasMatchingResource(Predicate<String> predicate);
  public A withResources(List<String> resources);
  public A withResources(java.lang.String... resources);
  public Boolean hasResources();
  public String getScope();
  public A withScope(String scope);
  public Boolean hasScope();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1alpha1/NamedRuleWithOperationsFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface NamedRuleWithOperationsFluent<A extends NamedRuleWithOperationsFluent<A>> extends Fluent<A>{
  public A addToApiGroups(int index,String item);
  public A setToApiGroups(int index,String item);
  public A addToApiGroups(java.lang.String... items);
  public A addAllToApiGroups(Collection<String> items);
  public A removeFromApiGroups(java.lang.String... items);
  public A removeAllFromApiGroups(Collection<String> items);
  public List<String> getApiGroups();
  public String getApiGroup(int index);
  public String getFirstApiGroup();
  public String getLastApiGroup();
  public String getMatchingApiGroup(Predicate<String> predicate);
  public Boolean hasMatchingApiGroup(Predicate<String> predicate);
  public A withApiGroups(List<String> apiGroups);
  public A withApiGroups(java.lang.String... apiGroups);
  public Boolean hasApiGroups();
  public A addToApiVersions(int index,String item);
  public A setToApiVersions(int index,String item);
  public A addToApiVersions(java.lang.String... items);
  public A addAllToApiVersions(Collection<String> items);
  public A removeFromApiVersions(java.lang.String... items);
  public A removeAllFromApiVersions(Collection<String> items);
  public List<String> getApiVersions();
  public String getApiVersion(int index);
  public String getFirstApiVersion();
  public String getLastApiVersion();
  public String getMatchingApiVersion(Predicate<String> predicate);
  public Boolean hasMatchingApiVersion(Predicate<String> predicate);
  public A withApiVersions(List<String> apiVersions);
  public A withApiVersions(java.lang.String... apiVersions);
  public Boolean hasApiVersions();
  public A addToOperations(int index,String item);
  public A setToOperations(int index,String item);
  public A addToOperations(java.lang.String... items);
  public A addAllToOperations(Collection<String> items);
  public A removeFromOperations(java.lang.String... items);
  public A removeAllFromOperations(Collection<String> items);
  public List<String> getOperations();
  public String getOperation(int index);
  public String getFirstOperation();
  public String getLastOperation();
  public String getMatchingOperation(Predicate<String> predicate);
  public Boolean hasMatchingOperation(Predicate<String> predicate);
  public A withOperations(List<String> operations);
  public A withOperations(java.lang.String... operations);
  public Boolean hasOperations();
  public A addToResourceNames(int index,String item);
  public A setToResourceNames(int index,String item);
  public A addToResourceNames(java.lang.String... items);
  public A addAllToResourceNames(Collection<String> items);
  public A removeFromResourceNames(java.lang.String... items);
  public A removeAllFromResourceNames(Collection<String> items);
  public List<String> getResourceNames();
  public String getResourceName(int index);
  public String getFirstResourceName();
  public String getLastResourceName();
  public String getMatchingResourceName(Predicate<String> predicate);
  public Boolean hasMatchingResourceName(Predicate<String> predicate);
  public A withResourceNames(List<String> resourceNames);
  public A withResourceNames(java.lang.String... resourceNames);
  public Boolean hasResourceNames();
  public A addToResources(int index,String item);
  public A setToResources(int index,String item);
  public A addToResources(java.lang.String... items);
  public A addAllToResources(Collection<String> items);
  public A removeFromResources(java.lang.String... items);
  public A removeAllFromResources(Collection<String> items);
  public List<String> getResources();
  public String getResource(int index);
  public String getFirstResource();
  public String getLastResource();
  public String getMatchingResource(Predicate<String> predicate);
  public Boolean hasMatchingResource(Predicate<String> predicate);
  public A withResources(List<String> resources);
  public A withResources(java.lang.String... resources);
  public Boolean hasResources();
  public String getScope();
  public A withScope(String scope);
  public Boolean hasScope();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
